@@ -319,7 +319,8 @@ map <- function(input.seq,tol=10E-5, verbose=FALSE,
     while(final.map$loglike == -Inf){
       idx <- idx + 1
       tol.up <- tol*(idx*10)
-      warning(paste0("HMM likelihood returned with this tolerance was -Inf. Tolerance used:", tol.up))
+      warning("The EM tolerance was increased.")
+      cat(paste0("HMM likelihood returned with this tolerance was -Inf. Tolerance used:", tol.up))
       final.map <- est_map_hmm_out(geno=t(input.seq$data.name$geno[,seq.num]),
                                    error = input.seq$data.name$error[seq.num + 
                                                                        rep(c(0:(input.seq$data.name$n.ind-1))*input.seq$data.name$n.mar, 
@@ -330,6 +331,8 @@ map <- function(input.seq,tol=10E-5, verbose=FALSE,
                                    verbose=FALSE,
                                    tol=tol.up)
       
+      if(is.na(final.map$loglike)) final.map$loglike <- -Inf
+      
     }
     
     return(structure(list(seq.num=seq.num, seq.phases=seq.phases, seq.rf=final.map$rf,
